@@ -7,7 +7,7 @@ function(f3,digits=3){
     n <- sum(f3)
     p3 <- f3/n
     if(length(dim(f3)) != 3){
-        stop("f3 is'not a 3 way table\n")
+        stop("f3 is not a 3 way table\n")
     }
     pi <- apply(p3, 1, sum)
     pj <- apply(p3, 2, sum)
@@ -17,6 +17,10 @@ function(f3,digits=3){
     pij <- apply(p3, c(1, 2), sum)
     pik <- apply(p3, c(1, 3), sum)
     pjk <- apply(p3, c(2, 3), sum)
+#alpha<- (pij%o%pk)+aperm(pik%o%pj,c(1,3,2))+aperm(pjk%o%pi,c(3,1,2))-2*pijk
+#pijktab<-((p3-alpha))
+#pijkint<-n*(sum((p3-alpha)^2/pijk)) #good
+
     khij <- n * (sum(pij^2/(pi %o% pj)) - 1)
     khik <- n * (sum(pik^2/(pi %o% pk)) - 1)
     khjk <- n * (sum(pjk^2/(pj %o% pk)) - 1)
@@ -32,9 +36,10 @@ function(f3,digits=3){
     dtot<-dij+dik+djk+dijk
     df <- c(dij, dik, djk, dijk, dtot)
    pvalue= 1 - pchisq(x, df)
-    z <- rbind(x, y, df,pvalue)
-    nomr <- c("Index", "% of Inertia", "df","p-value")
+x2<-x/df
+    z <- rbind(x, y, df,pvalue,x2)
+    nomr <- c("Index", "% of Inertia", "df","p-value", "X2/df")
     dimnames(z) <- list(nomr, nom)
     z <- round(z, digits = digits)
-    list(z = z)
+    list(z = z,pij=pij,pik=pik,pjk=pjk)
 }
